// SPDX-License-Identifier: MIT

pragma solidity ^0.8.19;

import {ENS} from "@ens/contracts/registry/ENS.sol";
import {IERC20} from "@openzeppelin/contracts/token/ERC20/IERC20.sol";

import {IGovernance} from "common/interfaces/IGovernance.sol";
import {IGnosisSafe} from "common/interfaces/IGnosisSafe.sol";

import {TornadoAddresses} from "common/TornadoAddresses.sol";

abstract contract TornadoProposal is TornadoAddresses {
    function executeProposal() public virtual;

    function getMultisig() internal pure returns (IGnosisSafe) {
        return IGnosisSafe(getMultisigAddress());
    }

    function getENS() internal pure returns (ENS) {
        return ENS(getENSAddress());
    }

    function getTornToken() internal pure returns (IERC20) {
        return IERC20(getTornTokenAddress());
    }

    function getGovernance() internal pure returns (IGovernance) {
        return IGovernance(getGovernanceProxyAddress());
    }
}
